Method

Enum Method 

pub enum Method<T> {
    Get,
    Post(T),
}
The HTTP request method in use with this ACME request.

All ACME requests use POST under the hood, since they all contain a JWS-via-JOSE token to validate that the request is coming from the account holder. However, sometimes the ACME server wants the request to have GET semantics. In those cases, the payload will be the empty string.

Variants



Get

GET-as-POST request with an empty string payload



Post(T)

POST request with a specific JSON payload.